@@ -124,9 +124,15 @@ void SPIRVDecorate::encode(spv_ostream &O) const {
   case DecorationUserSemantic:
     SPIRVDecorateUserSemanticAttr::encodeLiterals(Encoder, Literals);
     break;
-  case spv::internal::DecorationHostAccessINTEL:
+  case internal::DecorationHostAccessINTEL:
+    SPIRVDecorateHostAccessINTELLegacy::encodeLiterals(Encoder, Literals);
+    break;
+  case DecorationHostAccessINTEL:
     SPIRVDecorateHostAccessINTEL::encodeLiterals(Encoder, Literals);
     break;
+  case DecorationInitModeINTEL:
+    SPIRVDecorateInitModeINTEL::encodeLiterals(Encoder, Literals);
+    break;
   default:
     Encoder << Literals;
   }
@@ -153,7 +159,10 @@ void SPIRVDecorate::decode(std::istream &I) {
   case DecorationUserSemantic:
     SPIRVDecorateUserSemanticAttr::decodeLiterals(Decoder, Literals);
     break;
-  case spv::internal::DecorationHostAccessINTEL:
+  case internal::DecorationHostAccessINTEL:
+    SPIRVDecorateHostAccessINTELLegacy::decodeLiterals(Decoder, Literals);
+    break;
+  case DecorationHostAccessINTEL:
     SPIRVDecorateHostAccessINTEL::decodeLiterals(Decoder, Literals);
     break;
   default:
@@ -243,7 +252,7 @@ void SPIRVGroupDecorateGeneric::decode(std::istream &I) {
 
 void SPIRVGroupDecorate::decorateTargets() {
   for (auto &I : Targets) {
-    auto Target = getOrCreate(I);
+    auto *Target = getOrCreate(I);
     for (auto &Dec : DecorationGroup->getDecorations()) {
       assert(Dec->isDecorate());
       Target->addDecorate(static_cast<SPIRVDecorate *>(Dec));
@@ -253,7 +262,7 @@ void SPIRVGroupDecorate::decorateTargets() {
 
 void SPIRVGroupMemberDecorate::decorateTargets() {
   for (auto &I : Targets) {
-    auto Target = getOrCreate(I);
+    auto *Target = getOrCreate(I);
     for (auto &Dec : DecorationGroup->getDecorations()) {
       assert(Dec->isMemberDecorate());
       Target->addMemberDecorate(static_cast<SPIRVMemberDecorate *>(Dec));
